# Simple Service Search

This agent searches for a service on the SOEF.

## Description

This agent is used in the "Guide on Writing a Skill" section of the documentation. On start, it starts repeatedly searching on the `SOEF`.

## Links

* <a href="https://docs.fetch.ai/aea/skill-guide/" target="_blank">Guide on Building a Skill</a>
